pub struct ProjectContext {
pub root: PathBuf,
pub rust_files: Vec<PathBuf>,
pub markdown_files: Vec<PathBuf>,
pub yaml_files: Vec<PathBuf>,
pub makefile_files: Vec<PathBuf>,
pub code_facts: Vec<CodeFact>,
}Expand description
Everything an analyzer needs to answer questions about the project.
Owns parsed artifacts so each file is parsed at most once per run.
Fields
root: PathBufrust_files: Vec<PathBuf>markdown_files: Vec<PathBuf>yaml_files: Vec<PathBuf>makefile_files: Vec<PathBuf>code_facts: Vec<CodeFact>Implementations